Module: Bones::Plugins::Git::GemOverrides
- Defined in:
- lib/bones/plugins/git.rb
Overview
Override the manifest method in the Gem plugin so that the list of
filese to package is provided from git and its include / exclude rules.
Instance Method Summary collapse
-
#manifest ⇒ Object
This method uses the
git ls-filescommand to list the files that should be included in the packaging process for the project.
Instance Method Details
#manifest ⇒ Object
This method uses the git ls-files command to list the files that
should be included in the packaging process for the project.
Returns an array of filenames as Strings.
110 111 112 |
# File 'lib/bones/plugins/git.rb', line 110 def manifest %x{git ls-files}.split end |